//
//  ViewController.m
//  SCGraphView
//
//  Created by Anton Domashnev on 25.02.13.
//  Copyright (c) 2013 Anton Domashnev. All rights reserved.
//

#import "ViewController.h"
#import "GraphDataObject.h"
#import "GraphView.h"
#import "MBProgressHUD.h"

@interface ViewController ()<GraphViewDelegate>

@property (nonatomic, strong) GraphView *graphView;
@property (nonatomic, strong) MBProgressHUD *hud;

@end

@implementation ViewController
@synthesize slideMenuBtn;
@synthesize db;

- (NSInteger)randomBetweenFirst:(int)start andSecond:(int)end{
    
    return arc4random_uniform(end - start) + start;
}

-(void)viewWillAppear:(BOOL)animated{
    
    [super viewWillDisappear:animated];
	[[self navigationController] setNavigationBarHidden:NO animated:YES];
    [self.navigationController.navigationBar.topItem setTitle:@"Peak Flow Chart"];
    [self.navigationController.navigationBar.topItem setRightBarButtonItem:nil];

}

- (void)viewDidLoad
{
    [super viewDidLoad];
    self.view.layer.shadowOpacity = 0.75f;
    self.view.layer.shadowRadius = 10.0f;
    self.view.layer.shadowColor = [UIColor blackColor].CGColor;
    
    
    if (![self.slidingViewController.underLeftViewController isKindOfClass:[SlideMenuViewController class]]) {
        self.slidingViewController.underLeftViewController  = [self.storyboard instantiateViewControllerWithIdentifier:@"SlideMenu"];
    }
    
    self.slideMenuBtn = [UIButton buttonWithType:UIButtonTypeCustom];
    slideMenuBtn.frame = CGRectMake(8, 10, 34, 24);
    [slideMenuBtn setBackgroundImage:[UIImage imageNamed:@"Button.png"] forState:UIControlStateNormal];
    [slideMenuBtn addTarget:self action:@selector(revealMenu:) forControlEvents:UIControlEventTouchUpInside];
    
    
    [self.view addSubview:self.slideMenuBtn];
   

    BOOL isEmpty = [self addGraphView];
    /////////////////////
    if (isEmpty) {
        
        UIAlertView *message = [[UIAlertView alloc] initWithTitle:@"Peak Flow Chart"
                                                          message:@"Don't forget to enter your daily peak flow mesurements :)"
                                                         delegate:nil
                                                cancelButtonTitle:@"OK"
                                                otherButtonTitles:nil];
        [message show];
    }
    
    
    
}


- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark GraphView

- (BOOL)addGraphView{
    NSMutableDictionary *dictionaryObjects = [[NSMutableDictionary alloc] init];
    db = [[database alloc] init];    
    dictionaryObjects = [db selectFromPeakFlow];
    BOOL isEmpty = ([dictionaryObjects count] == 0);
    
    self.hud = [MBProgressHUD showHUDAddedTo:self.view animated:YES];
    self.hud.labelText = NSLocalizedString(@"Loading graph data...", @"");
    
    dispatch_async(dispatch_get_global_queue(DISPATCH_QUEUE_PRIORITY_DEFAULT, 0), ^{
        
        NSCalendar *gregorian = [[NSCalendar alloc] initWithCalendarIdentifier:NSGregorianCalendar];
        NSDateComponents *comp = [gregorian components:(NSYearCalendarUnit | NSMonthCalendarUnit | NSDayCalendarUnit) fromDate:[NSDate date]];
        [comp setDay:1];
        //NSDate *firstDayOfMonthDate = [gregorian dateFromComponents:comp];
        
        NSDate *startDate = [gregorian dateFromComponents:comp];//[NSDate dateWithTimeIntervalSince1970: 1351036800];
        NSDate *endDate = [NSDate date];

        if (isEmpty) {
            NSDate *now = [NSDate date];
            NSCalendar *calendar = [[NSCalendar alloc] initWithCalendarIdentifier:NSGregorianCalendar];
            NSDateComponents *components = [calendar components:NSYearCalendarUnit|NSMonthCalendarUnit|NSDayCalendarUnit fromDate:now];
            [components setHour:10];
            
            NSDate *today10am = [calendar dateFromComponents:components];
            NSDateFormatter *dateFormatter = [[NSDateFormatter alloc] init];
            [dateFormatter setDateFormat:@"yyyy-MM-dd HH:mm:ss ZZZZ"];
            
            
            NSString *PeakFlowString = [dateFormatter stringFromDate:today10am];
            
            [dictionaryObjects setValue:@"0" forKeyPath:PeakFlowString];

        }
        
        NSArray *graphObjects = [NSArray arrayWithArray:[GraphDataObject graphTest:dictionaryObjects]];


        
        dispatch_async(dispatch_get_main_queue(), ^{
            
            if([graphObjects count] > 0){

                self.graphView = [[GraphView alloc] initWithFrame:DEFAULT_GRAPH_VIEW_FRAME objectsArray:graphObjects startDate:startDate endDate:endDate delegate:self];
                
                [self.view insertSubview:self.graphView atIndex:0];
            }
        });
    });
    return isEmpty;
}

#pragma mark GraphViewDelegate

- (void)graphViewDidUpdate:(GraphView *)view{
    
    [MBProgressHUD hideHUDForView:self.view animated:YES];
    
    self.hud = nil;
}

- (void)graphViewWillUpdate:(GraphView *)view{
    
    if(!self.hud){
        
        self.hud = [MBProgressHUD showHUDAddedTo:self.view animated:YES];
        self.hud.labelText = NSLocalizedString(@"Loading graph data...", @"");
    }
}
- (IBAction)revealMenu:(id)sender
{
    [self.slidingViewController anchorTopViewTo:ECRight];
}

@end
